@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2001-2019 Marco d'Itri <md@linux.it>.
+ * Copyright (C) 2001-2021 Marco d'Itri <md@linux.it>.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -283,8 +283,18 @@ int main(int argc, char *argv[])
 	rounds_str[0] = '\0';
 
     if (salt_arg && salt_arg[0] == '$')
+	/* the salt begins with the prefix which specifies the method */
 	salt = NOFAIL(strdup(salt_arg));
-    else if (salt_arg && salt_arg[0] != '\0') {
+    else if (salt_prefix && salt_arg && strchr(salt_arg, '$')) {
+	/* looks like a salt, but with no initial method prefix */
+	salt = NOFAIL(malloc(strlen(salt_prefix) + strlen(rounds_str)
+		+ strlen(salt_arg) + 1));
+	*salt = '\0';
+	strcat(salt, salt_prefix);
+	strcat(salt, rounds_str);
+	strcat(salt, salt_arg);
+    } else if (salt_arg && salt_arg[0] != '\0') {
+	/* just the salt string with no metadata */
 	unsigned int c = strlen(salt_arg);
 	if (c < salt_minlen || c > salt_maxlen) {
 	    if (salt_minlen == salt_maxlen)
@@ -309,6 +319,10 @@ int main(int argc, char *argv[])
 	    }
 	}
 
+	/*
+	 * Build the actual argument to crypt(3) by concatenating the
+	 * method prefix, the rounds metadata (if any) and the salt string.
+	 */
 	salt = NOFAIL(malloc(strlen(salt_prefix) + strlen(rounds_str)
 		+ strlen(salt_arg) + 1));
 	*salt = '\0';
@@ -316,6 +330,7 @@ int main(int argc, char *argv[])
 	strcat(salt, rounds_str);
 	strcat(salt, salt_arg);
     } else {
+	/* no salt was specified by the user, so generate one */
 #ifdef HAVE_SOLARIS_CRYPT_GENSALT
 	salt = crypt_gensalt(salt_prefix, NULL);
 	if (!salt) {
@@ -522,7 +537,7 @@ void NORETURN display_help(int error)
 void display_version(void)
 {
     printf("mkpasswd %s\n\n", VERSION);
-    puts("Copyright (C) 2001-2019 Marco d'Itri\n"
+    puts("Copyright (C) 2001-2021 Marco d'Itri\n"
 "This is free software; see the source for copying conditions.  There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.");
 }
